@@ -3,6 +3,11 @@ use walkdir::WalkDir;
 
 fn main() {
     let mut cfg = Build::new();
+    cfg.compiler("clang");
+    cfg.flag("-nostdlibinc");
+    cfg.flag("-fno-stack-protector");
+    cfg.flag("-fno-profile-instr-generate");
+    cfg.flag("-fno-coverage-mapping");
     cfg.define("COMPILER_RT_HAS_ATOMICS", "1");
 
     let sources = [
